@@ -138,7 +138,8 @@ def update_order(account, order):
 
 def update_list_profit_loss(account):
     order = pd.read_csv('%s_order.csv' % account, index_col='ts')
-    if ((order['action'][-1] == 'Sell').bool()):
+    last_trade = order.tail(1)
+    if ((last_trade['action'] == 'Sell').bool()):
         pnl = (order['price'][-1] - order['price'][-2]) * 200 - \
             order['fee'][-1] - order['fee'][-2] - \
             order['tax'][-1] - order['tax'][-2]
